Documentation
¶
Overview ¶
Package cmd defines all cobra commands for the flow CLI.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrNoAgent = errors.New("no agents configured; specify a command with -- or add agents to config")
ErrNoAgent is returned when no agents are configured and no command is given.
Functions ¶
func NewRootCmd ¶
NewRootCmd returns the root command for use by doc generation tools.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.