cmd

package
v1.4.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 27, 2026 License: MIT Imports: 22 Imported by: 0

Documentation

Overview

Package cmd defines all cobra commands for the flow CLI.

Index

Constants

This section is empty.

Variables

var ErrNoAgent = errors.New("no agents configured; specify a command with -- or add agents to config")

ErrNoAgent is returned when no agents are configured and no command is given.

Functions

func Execute

func Execute() error

Execute runs the root command.

func NewRootCmd

func NewRootCmd() *cobra.Command

NewRootCmd returns the root command for use by doc generation tools.

Types

This section is empty.

Jump to