cmd

package
v0.3.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 20, 2026 License: MIT Imports: 15 Imported by: 0

Documentation

Overview

Package cmd defines all cobra commands for the flow CLI.

Index

Constants

This section is empty.

Variables

var ErrNoCommand = errors.New("no command specified after '--'")

ErrNoCommand is returned when no command is specified after --.

Functions

func Execute

func Execute() error

Execute runs the root command.

func NewRootCmd

func NewRootCmd() *cobra.Command

NewRootCmd returns the root command for use by doc generation tools.

Types

This section is empty.

Jump to