Documentation
¶
Overview ¶
Package cmd defines all cobra commands for the flow CLI.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrNoCommand = errors.New("no command specified after '--'")
ErrNoCommand is returned when no command is specified after --.
Functions ¶
func NewRootCmd ¶
NewRootCmd returns the root command for use by doc generation tools.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.